# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: stats.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='stats.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x0bstats.proto\"\xe0\x02\n\x10\x64ump_stats_entry\x12\x15\n\rfreezing_time\x18\x01 \x02(\r\x12\x13\n\x0b\x66rozen_time\x18\x02 \x02(\r\x12\x14\n\x0cmemdump_time\x18\x03 \x02(\r\x12\x15\n\rmemwrite_time\x18\x04 \x02(\r\x12\x15\n\rpages_scanned\x18\x05 \x02(\x04\x12\x1c\n\x14pages_skipped_parent\x18\x06 \x02(\x04\x12\x15\n\rpages_written\x18\x07 \x02(\x04\x12\x15\n\rirmap_resolve\x18\x08 \x01(\r\x12\x12\n\npages_lazy\x18\t \x02(\x04\x12\x12\n\npage_pipes\x18\n \x01(\x04\x12\x16\n\x0epage_pipe_bufs\x18\x0b \x01(\x04\x12\x17\n\x0fshpages_scanned\x18\x0c \x01(\x04\x12\x1e\n\x16shpages_skipped_parent\x18\r \x01(\x04\x12\x17\n\x0fshpages_written\x18\x0e \x01(\x04\"\x8c\x01\n\x13restore_stats_entry\x12\x16\n\x0epages_compared\x18\x01 \x02(\x04\x12\x19\n\x11pages_skipped_cow\x18\x02 \x02(\x04\x12\x14\n\x0c\x66orking_time\x18\x03 \x02(\r\x12\x14\n\x0crestore_time\x18\x04 \x02(\r\x12\x16\n\x0epages_restored\x18\x05 \x01(\x04\"U\n\x0bstats_entry\x12\x1f\n\x04\x64ump\x18\x01 \x01(\x0b\x32\x11.dump_stats_entry\x12%\n\x07restore\x18\x02 \x01(\x0b\x32\x14.restore_stats_entry')
)




_DUMP_STATS_ENTRY = _descriptor.Descriptor(
  name='dump_stats_entry',
  full_name='dump_stats_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='freezing_time', full_name='dump_stats_entry.freezing_time', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frozen_time', full_name='dump_stats_entry.frozen_time', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='memdump_time', full_name='dump_stats_entry.memdump_time', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='memwrite_time', full_name='dump_stats_entry.memwrite_time', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pages_scanned', full_name='dump_stats_entry.pages_scanned', index=4,
      number=5, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pages_skipped_parent', full_name='dump_stats_entry.pages_skipped_parent', index=5,
      number=6, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pages_written', full_name='dump_stats_entry.pages_written', index=6,
      number=7, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='irmap_resolve', full_name='dump_stats_entry.irmap_resolve', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pages_lazy', full_name='dump_stats_entry.pages_lazy', index=8,
      number=9, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page_pipes', full_name='dump_stats_entry.page_pipes', index=9,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page_pipe_bufs', full_name='dump_stats_entry.page_pipe_bufs', index=10,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shpages_scanned', full_name='dump_stats_entry.shpages_scanned', index=11,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shpages_skipped_parent', full_name='dump_stats_entry.shpages_skipped_parent', index=12,
      number=13, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shpages_written', full_name='dump_stats_entry.shpages_written', index=13,
      number=14, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16,
  serialized_end=368,
)


_RESTORE_STATS_ENTRY = _descriptor.Descriptor(
  name='restore_stats_entry',
  full_name='restore_stats_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pages_compared', full_name='restore_stats_entry.pages_compared', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pages_skipped_cow', full_name='restore_stats_entry.pages_skipped_cow', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='forking_time', full_name='restore_stats_entry.forking_time', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='restore_time', full_name='restore_stats_entry.restore_time', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pages_restored', full_name='restore_stats_entry.pages_restored', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=371,
  serialized_end=511,
)


_STATS_ENTRY = _descriptor.Descriptor(
  name='stats_entry',
  full_name='stats_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dump', full_name='stats_entry.dump', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='restore', full_name='stats_entry.restore', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=513,
  serialized_end=598,
)

_STATS_ENTRY.fields_by_name['dump'].message_type = _DUMP_STATS_ENTRY
_STATS_ENTRY.fields_by_name['restore'].message_type = _RESTORE_STATS_ENTRY
DESCRIPTOR.message_types_by_name['dump_stats_entry'] = _DUMP_STATS_ENTRY
DESCRIPTOR.message_types_by_name['restore_stats_entry'] = _RESTORE_STATS_ENTRY
DESCRIPTOR.message_types_by_name['stats_entry'] = _STATS_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

dump_stats_entry = _reflection.GeneratedProtocolMessageType('dump_stats_entry', (_message.Message,), dict(
  DESCRIPTOR = _DUMP_STATS_ENTRY,
  __module__ = 'stats_pb2'
  # @@protoc_insertion_point(class_scope:dump_stats_entry)
  ))
_sym_db.RegisterMessage(dump_stats_entry)

restore_stats_entry = _reflection.GeneratedProtocolMessageType('restore_stats_entry', (_message.Message,), dict(
  DESCRIPTOR = _RESTORE_STATS_ENTRY,
  __module__ = 'stats_pb2'
  # @@protoc_insertion_point(class_scope:restore_stats_entry)
  ))
_sym_db.RegisterMessage(restore_stats_entry)

stats_entry = _reflection.GeneratedProtocolMessageType('stats_entry', (_message.Message,), dict(
  DESCRIPTOR = _STATS_ENTRY,
  __module__ = 'stats_pb2'
  # @@protoc_insertion_point(class_scope:stats_entry)
  ))
_sym_db.RegisterMessage(stats_entry)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sysctl.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='sysctl.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x0csysctl.proto\"E\n\x0csysctl_entry\x12\x19\n\x04type\x18\x01 \x02(\x0e\x32\x0b.SysctlType\x12\x0c\n\x04iarg\x18\x02 \x01(\x05\x12\x0c\n\x04sarg\x18\x03 \x01(\t*%\n\nSysctlType\x12\x0b\n\x07\x43TL_STR\x10\x05\x12\n\n\x06\x43TL_32\x10\x06')
)

_SYSCTLTYPE = _descriptor.EnumDescriptor(
  name='SysctlType',
  full_name='SysctlType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CTL_STR', index=0, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CTL_32', index=1, number=6,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=87,
  serialized_end=124,
)
_sym_db.RegisterEnumDescriptor(_SYSCTLTYPE)

SysctlType = enum_type_wrapper.EnumTypeWrapper(_SYSCTLTYPE)
CTL_STR = 5
CTL_32 = 6



_SYSCTL_ENTRY = _descriptor.Descriptor(
  name='sysctl_entry',
  full_name='sysctl_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='sysctl_entry.type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=5,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='iarg', full_name='sysctl_entry.iarg', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sarg', full_name='sysctl_entry.sarg', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16,
  serialized_end=85,
)

_SYSCTL_ENTRY.fields_by_name['type'].enum_type = _SYSCTLTYPE
DESCRIPTOR.message_types_by_name['sysctl_entry'] = _SYSCTL_ENTRY
DESCRIPTOR.enum_types_by_name['SysctlType'] = _SYSCTLTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

sysctl_entry = _reflection.GeneratedProtocolMessageType('sysctl_entry', (_message.Message,), dict(
  DESCRIPTOR = _SYSCTL_ENTRY,
  __module__ = 'sysctl_pb2'
  # @@protoc_insertion_point(class_scope:sysctl_entry)
  ))
_sym_db.RegisterMessage(sysctl_entry)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: core-ppc64.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='core-ppc64.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x10\x63ore-ppc64.proto\x1a\nopts.proto\"\xc2\x01\n\x15user_ppc64_regs_entry\x12\x0b\n\x03gpr\x18\x01 \x03(\x04\x12\x0b\n\x03nip\x18\x02 \x02(\x04\x12\x0b\n\x03msr\x18\x03 \x02(\x04\x12\x11\n\torig_gpr3\x18\x04 \x02(\x04\x12\x0b\n\x03\x63tr\x18\x05 \x02(\x04\x12\x0c\n\x04link\x18\x06 \x02(\x04\x12\x0b\n\x03xer\x18\x07 \x02(\x04\x12\x0b\n\x03\x63\x63r\x18\x08 \x02(\x04\x12\x0c\n\x04trap\x18\t \x02(\x04\x12\x0e\n\x06texasr\x18\n \x01(\x04\x12\r\n\x05tfhar\x18\x0b \x01(\x04\x12\r\n\x05tfiar\x18\x0c \x01(\x04\"*\n\x18user_ppc64_fpstate_entry\x12\x0e\n\x06\x66pregs\x18\x01 \x03(\x04\":\n\x18user_ppc64_vrstate_entry\x12\x0e\n\x06vrregs\x18\x01 \x03(\x04\x12\x0e\n\x06vrsave\x18\x02 \x02(\r\",\n\x19user_ppc64_vsxstate_entry\x12\x0f\n\x07vsxregs\x18\x01 \x03(\x04\"\xc8\x01\n\x18user_ppc64_tm_regs_entry\x12&\n\x06gpregs\x18\x01 \x02(\x0b\x32\x16.user_ppc64_regs_entry\x12*\n\x07\x66pstate\x18\x02 \x01(\x0b\x32\x19.user_ppc64_fpstate_entry\x12*\n\x07vrstate\x18\x03 \x01(\x0b\x32\x19.user_ppc64_vrstate_entry\x12,\n\x08vsxstate\x18\x04 \x01(\x0b\x32\x1a.user_ppc64_vsxstate_entry\"\x93\x02\n\x11thread_info_ppc64\x12\x1d\n\x0e\x63lear_tid_addr\x18\x01 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12-\n\x06gpregs\x18\x02 \x02(\x0b\x32\x16.user_ppc64_regs_entryB\x05\xd2?\x02\x08\x01\x12*\n\x07\x66pstate\x18\x03 \x01(\x0b\x32\x19.user_ppc64_fpstate_entry\x12*\n\x07vrstate\x18\x04 \x01(\x0b\x32\x19.user_ppc64_vrstate_entry\x12,\n\x08vsxstate\x18\x05 \x01(\x0b\x32\x1a.user_ppc64_vsxstate_entry\x12*\n\x07tmstate\x18\x06 \x01(\x0b\x32\x19.user_ppc64_tm_regs_entry')
  ,
  dependencies=[opts__pb2.DESCRIPTOR,])




_USER_PPC64_REGS_ENTRY = _descriptor.Descriptor(
  name='user_ppc64_regs_entry',
  full_name='user_ppc64_regs_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gpr', full_name='user_ppc64_regs_entry.gpr', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nip', full_name='user_ppc64_regs_entry.nip', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='msr', full_name='user_ppc64_regs_entry.msr', index=2,
      number=3, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='orig_gpr3', full_name='user_ppc64_regs_entry.orig_gpr3', index=3,
      number=4, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ctr', full_name='user_ppc64_regs_entry.ctr', index=4,
      number=5, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='link', full_name='user_ppc64_regs_entry.link', index=5,
      number=6, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='xer', full_name='user_ppc64_regs_entry.xer', index=6,
      number=7, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ccr', full_name='user_ppc64_regs_entry.ccr', index=7,
      number=8, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trap', full_name='user_ppc64_regs_entry.trap', index=8,
      number=9, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='texasr', full_name='user_ppc64_regs_entry.texasr', index=9,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tfhar', full_name='user_ppc64_regs_entry.tfhar', index=10,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tfiar', full_name='user_ppc64_regs_entry.tfiar', index=11,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33,
  serialized_end=227,
)


_USER_PPC64_FPSTATE_ENTRY = _descriptor.Descriptor(
  name='user_ppc64_fpstate_entry',
  full_name='user_ppc64_fpstate_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fpregs', full_name='user_ppc64_fpstate_entry.fpregs', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=229,
  serialized_end=271,
)


_USER_PPC64_VRSTATE_ENTRY = _descriptor.Descriptor(
  name='user_ppc64_vrstate_entry',
  full_name='user_ppc64_vrstate_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vrregs', full_name='user_ppc64_vrstate_entry.vrregs', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vrsave', full_name='user_ppc64_vrstate_entry.vrsave', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=273,
  serialized_end=331,
)


_USER_PPC64_VSXSTATE_ENTRY = _descriptor.Descriptor(
  name='user_ppc64_vsxstate_entry',
  full_name='user_ppc64_vsxstate_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vsxregs', full_name='user_ppc64_vsxstate_entry.vsxregs', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=333,
  serialized_end=377,
)


_USER_PPC64_TM_REGS_ENTRY = _descriptor.Descriptor(
  name='user_ppc64_tm_regs_entry',
  full_name='user_ppc64_tm_regs_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gpregs', full_name='user_ppc64_tm_regs_entry.gpregs', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fpstate', full_name='user_ppc64_tm_regs_entry.fpstate', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vrstate', full_name='user_ppc64_tm_regs_entry.vrstate', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vsxstate', full_name='user_ppc64_tm_regs_entry.vsxstate', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=380,
  serialized_end=580,
)


_THREAD_INFO_PPC64 = _descriptor.Descriptor(
  name='thread_info_ppc64',
  full_name='thread_info_ppc64',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='clear_tid_addr', full_name='thread_info_ppc64.clear_tid_addr', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gpregs', full_name='thread_info_ppc64.gpregs', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fpstate', full_name='thread_info_ppc64.fpstate', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vrstate', full_name='thread_info_ppc64.vrstate', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vsxstate', full_name='thread_info_ppc64.vsxstate', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tmstate', full_name='thread_info_ppc64.tmstate', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=583,
  serialized_end=858,
)

_USER_PPC64_TM_REGS_ENTRY.fields_by_name['gpregs'].message_type = _USER_PPC64_REGS_ENTRY
_USER_PPC64_TM_REGS_ENTRY.fields_by_name['fpstate'].message_type = _USER_PPC64_FPSTATE_ENTRY
_USER_PPC64_TM_REGS_ENTRY.fields_by_name['vrstate'].message_type = _USER_PPC64_VRSTATE_ENTRY
_USER_PPC64_TM_REGS_ENTRY.fields_by_name['vsxstate'].message_type = _USER_PPC64_VSXSTATE_ENTRY
_THREAD_INFO_PPC64.fields_by_name['gpregs'].message_type = _USER_PPC64_REGS_ENTRY
_THREAD_INFO_PPC64.fields_by_name['fpstate'].message_type = _USER_PPC64_FPSTATE_ENTRY
_THREAD_INFO_PPC64.fields_by_name['vrstate'].message_type = _USER_PPC64_VRSTATE_ENTRY
_THREAD_INFO_PPC64.fields_by_name['vsxstate'].message_type = _USER_PPC64_VSXSTATE_ENTRY
_THREAD_INFO_PPC64.fields_by_name['tmstate'].message_type = _USER_PPC64_TM_REGS_ENTRY
DESCRIPTOR.message_types_by_name['user_ppc64_regs_entry'] = _USER_PPC64_REGS_ENTRY
DESCRIPTOR.message_types_by_name['user_ppc64_fpstate_entry'] = _USER_PPC64_FPSTATE_ENTRY
DESCRIPTOR.message_types_by_name['user_ppc64_vrstate_entry'] = _USER_PPC64_VRSTATE_ENTRY
DESCRIPTOR.message_types_by_name['user_ppc64_vsxstate_entry'] = _USER_PPC64_VSXSTATE_ENTRY
DESCRIPTOR.message_types_by_name['user_ppc64_tm_regs_entry'] = _USER_PPC64_TM_REGS_ENTRY
DESCRIPTOR.message_types_by_name['thread_info_ppc64'] = _THREAD_INFO_PPC64
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

user_ppc64_regs_entry = _reflection.GeneratedProtocolMessageType('user_ppc64_regs_entry', (_message.Message,), dict(
  DESCRIPTOR = _USER_PPC64_REGS_ENTRY,
  __module__ = 'core_ppc64_pb2'
  # @@protoc_insertion_point(class_scope:user_ppc64_regs_entry)
  ))
_sym_db.RegisterMessage(user_ppc64_regs_entry)

user_ppc64_fpstate_entry = _reflection.GeneratedProtocolMessageType('user_ppc64_fpstate_entry', (_message.Message,), dict(
  DESCRIPTOR = _USER_PPC64_FPSTATE_ENTRY,
  __module__ = 'core_ppc64_pb2'
  # @@protoc_insertion_point(class_scope:user_ppc64_fpstate_entry)
  ))
_sym_db.RegisterMessage(user_ppc64_fpstate_entry)

user_ppc64_vrstate_entry = _reflection.GeneratedProtocolMessageType('user_ppc64_vrstate_entry', (_message.Message,), dict(
  DESCRIPTOR = _USER_PPC64_VRSTATE_ENTRY,
  __module__ = 'core_ppc64_pb2'
  # @@protoc_insertion_point(class_scope:user_ppc64_vrstate_entry)
  ))
_sym_db.RegisterMessage(user_ppc64_vrstate_entry)

user_ppc64_vsxstate_entry = _reflection.GeneratedProtocolMessageType('user_ppc64_vsxstate_entry', (_message.Message,), dict(
  DESCRIPTOR = _USER_PPC64_VSXSTATE_ENTRY,
  __module__ = 'core_ppc64_pb2'
  # @@protoc_insertion_point(class_scope:user_ppc64_vsxstate_entry)
  ))
_sym_db.RegisterMessage(user_ppc64_vsxstate_entry)

user_ppc64_tm_regs_entry = _reflection.GeneratedProtocolMessageType('user_ppc64_tm_regs_entry', (_message.Message,), dict(
  DESCRIPTOR = _USER_PPC64_TM_REGS_ENTRY,
  __module__ = 'core_ppc64_pb2'
  # @@protoc_insertion_point(class_scope:user_ppc64_tm_regs_entry)
  ))
_sym_db.RegisterMessage(user_ppc64_tm_regs_entry)

thread_info_ppc64 = _reflection.GeneratedProtocolMessageType('thread_info_ppc64', (_message.Message,), dict(
  DESCRIPTOR = _THREAD_INFO_PPC64,
  __module__ = 'core_ppc64_pb2'
  # @@protoc_insertion_point(class_scope:thread_info_ppc64)
  ))
_sym_db.RegisterMessage(thread_info_ppc64)


_THREAD_INFO_PPC64.fields_by_name['clear_tid_addr'].has_options = True
_THREAD_INFO_PPC64.fields_by_name['clear_tid_addr']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_THREAD_INFO_PPC64.fields_by_name['gpregs'].has_options = True
_THREAD_INFO_PPC64.fields_by_name['gpregs']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: core-arm.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='core-arm.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x0e\x63ore-arm.proto\x1a\nopts.proto\"\xf5\x01\n\x13user_arm_regs_entry\x12\n\n\x02r0\x18\x01 \x02(\r\x12\n\n\x02r1\x18\x02 \x02(\r\x12\n\n\x02r2\x18\x03 \x02(\r\x12\n\n\x02r3\x18\x04 \x02(\r\x12\n\n\x02r4\x18\x05 \x02(\r\x12\n\n\x02r5\x18\x06 \x02(\r\x12\n\n\x02r6\x18\x07 \x02(\r\x12\n\n\x02r7\x18\x08 \x02(\r\x12\n\n\x02r8\x18\t \x02(\r\x12\n\n\x02r9\x18\n \x02(\r\x12\x0b\n\x03r10\x18\x0b \x02(\r\x12\n\n\x02\x66p\x18\x0c \x02(\r\x12\n\n\x02ip\x18\r \x02(\r\x12\n\n\x02sp\x18\x0e \x02(\r\x12\n\n\x02lr\x18\x0f \x02(\r\x12\n\n\x02pc\x18\x10 \x02(\r\x12\x0c\n\x04\x63psr\x18\x11 \x02(\r\x12\x0f\n\x07orig_r0\x18\x12 \x02(\r\"j\n\x17user_arm_vfpstate_entry\x12\x10\n\x08vfp_regs\x18\x01 \x03(\x04\x12\r\n\x05\x66pscr\x18\x02 \x02(\r\x12\r\n\x05\x66pexc\x18\x03 \x02(\r\x12\x0e\n\x06\x66pinst\x18\x04 \x02(\r\x12\x0f\n\x07\x66pinst2\x18\x05 \x02(\r\"\x95\x01\n\x0fthread_info_arm\x12\x1d\n\x0e\x63lear_tid_addr\x18\x01 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x0b\n\x03tls\x18\x02 \x02(\r\x12+\n\x06gpregs\x18\x03 \x02(\x0b\x32\x14.user_arm_regs_entryB\x05\xd2?\x02\x08\x01\x12)\n\x07\x66pstate\x18\x04 \x02(\x0b\x32\x18.user_arm_vfpstate_entry')
  ,
  dependencies=[opts__pb2.DESCRIPTOR,])




_USER_ARM_REGS_ENTRY = _descriptor.Descriptor(
  name='user_arm_regs_entry',
  full_name='user_arm_regs_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='r0', full_name='user_arm_regs_entry.r0', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='r1', full_name='user_arm_regs_entry.r1', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='r2', full_name='user_arm_regs_entry.r2', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='r3', full_name='user_arm_regs_entry.r3', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='r4', full_name='user_arm_regs_entry.r4', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='r5', full_name='user_arm_regs_entry.r5', index=5,
      number=6, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='r6', full_name='user_arm_regs_entry.r6', index=6,
      number=7, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='r7', full_name='user_arm_regs_entry.r7', index=7,
      number=8, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='r8', full_name='user_arm_regs_entry.r8', index=8,
      number=9, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='r9', full_name='user_arm_regs_entry.r9', index=9,
      number=10, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='r10', full_name='user_arm_regs_entry.r10', index=10,
      number=11, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fp', full_name='user_arm_regs_entry.fp', index=11,
      number=12, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ip', full_name='user_arm_regs_entry.ip', index=12,
      number=13, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sp', full_name='user_arm_regs_entry.sp', index=13,
      number=14, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lr', full_name='user_arm_regs_entry.lr', index=14,
      number=15, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pc', full_name='user_arm_regs_entry.pc', index=15,
      number=16, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cpsr', full_name='user_arm_regs_entry.cpsr', index=16,
      number=17, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='orig_r0', full_name='user_arm_regs_entry.orig_r0', index=17,
      number=18, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31,
  serialized_end=276,
)


_USER_ARM_VFPSTATE_ENTRY = _descriptor.Descriptor(
  name='user_arm_vfpstate_entry',
  full_name='user_arm_vfpstate_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vfp_regs', full_name='user_arm_vfpstate_entry.vfp_regs', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fpscr', full_name='user_arm_vfpstate_entry.fpscr', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fpexc', full_name='user_arm_vfpstate_entry.fpexc', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fpinst', full_name='user_arm_vfpstate_entry.fpinst', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fpinst2', full_name='user_arm_vfpstate_entry.fpinst2', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=278,
  serialized_end=384,
)


_THREAD_INFO_ARM = _descriptor.Descriptor(
  name='thread_info_arm',
  full_name='thread_info_arm',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='clear_tid_addr', full_name='thread_info_arm.clear_tid_addr', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tls', full_name='thread_info_arm.tls', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gpregs', full_name='thread_info_arm.gpregs', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fpstate', full_name='thread_info_arm.fpstate', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=387,
  serialized_end=536,
)

_THREAD_INFO_ARM.fields_by_name['gpregs'].message_type = _USER_ARM_REGS_ENTRY
_THREAD_INFO_ARM.fields_by_name['fpstate'].message_type = _USER_ARM_VFPSTATE_ENTRY
DESCRIPTOR.message_types_by_name['user_arm_regs_entry'] = _USER_ARM_REGS_ENTRY
DESCRIPTOR.message_types_by_name['user_arm_vfpstate_entry'] = _USER_ARM_VFPSTATE_ENTRY
DESCRIPTOR.message_types_by_name['thread_info_arm'] = _THREAD_INFO_ARM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

user_arm_regs_entry = _reflection.GeneratedProtocolMessageType('user_arm_regs_entry', (_message.Message,), dict(
  DESCRIPTOR = _USER_ARM_REGS_ENTRY,
  __module__ = 'core_arm_pb2'
  # @@protoc_insertion_point(class_scope:user_arm_regs_entry)
  ))
_sym_db.RegisterMessage(user_arm_regs_entry)

user_arm_vfpstate_entry = _reflection.GeneratedProtocolMessageType('user_arm_vfpstate_entry', (_message.Message,), dict(
  DESCRIPTOR = _USER_ARM_VFPSTATE_ENTRY,
  __module__ = 'core_arm_pb2'
  # @@protoc_insertion_point(class_scope:user_arm_vfpstate_entry)
  ))
_sym_db.RegisterMessage(user_arm_vfpstate_entry)

thread_info_arm = _reflection.GeneratedProtocolMessageType('thread_info_arm', (_message.Message,), dict(
  DESCRIPTOR = _THREAD_INFO_ARM,
  __module__ = 'core_arm_pb2'
  # @@protoc_insertion_point(class_scope:thread_info_arm)
  ))
_sym_db.RegisterMessage(thread_info_arm)


_THREAD_INFO_ARM.fields_by_name['clear_tid_addr'].has_options = True
_THREAD_INFO_ARM.fields_by_name['clear_tid_addr']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_THREAD_INFO_ARM.fields_by_name['gpregs'].has_options = True
_THREAD_INFO_ARM.fields_by_name['gpregs']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fh.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='fh.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x08\x66h.proto\x1a\nopts.proto\"U\n\x08\x66h_entry\x12\r\n\x05\x62ytes\x18\x01 \x02(\r\x12\x0c\n\x04type\x18\x02 \x02(\r\x12\x0e\n\x06handle\x18\x03 \x03(\x04\x12\x0c\n\x04path\x18\x04 \x01(\t\x12\x0e\n\x06mnt_id\x18\x05 \x01(\r\"I\n\x11irmap_cache_entry\x12\x17\n\x03\x64\x65v\x18\x01 \x02(\rB\n\xd2?\x02 \x01\xd2?\x02(\x01\x12\r\n\x05inode\x18\x02 \x02(\x04\x12\x0c\n\x04path\x18\x03 \x02(\t*!\n\x0e\x66h_entry_sizes\x12\x0f\n\x0bmin_entries\x10\x10')
  ,
  dependencies=[opts__pb2.DESCRIPTOR,])

_FH_ENTRY_SIZES = _descriptor.EnumDescriptor(
  name='fh_entry_sizes',
  full_name='fh_entry_sizes',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='min_entries', index=0, number=16,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=186,
  serialized_end=219,
)
_sym_db.RegisterEnumDescriptor(_FH_ENTRY_SIZES)

fh_entry_sizes = enum_type_wrapper.EnumTypeWrapper(_FH_ENTRY_SIZES)
min_entries = 16



_FH_ENTRY = _descriptor.Descriptor(
  name='fh_entry',
  full_name='fh_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='bytes', full_name='fh_entry.bytes', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='fh_entry.type', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='handle', full_name='fh_entry.handle', index=2,
      number=3, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path', full_name='fh_entry.path', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mnt_id', full_name='fh_entry.mnt_id', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24,
  serialized_end=109,
)


_IRMAP_CACHE_ENTRY = _descriptor.Descriptor(
  name='irmap_cache_entry',
  full_name='irmap_cache_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dev', full_name='irmap_cache_entry.dev', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002 \001\322?\002(\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inode', full_name='irmap_cache_entry.inode', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path', full_name='irmap_cache_entry.path', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=111,
  serialized_end=184,
)

DESCRIPTOR.message_types_by_name['fh_entry'] = _FH_ENTRY
DESCRIPTOR.message_types_by_name['irmap_cache_entry'] = _IRMAP_CACHE_ENTRY
DESCRIPTOR.enum_types_by_name['fh_entry_sizes'] = _FH_ENTRY_SIZES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

fh_entry = _reflection.GeneratedProtocolMessageType('fh_entry', (_message.Message,), dict(
  DESCRIPTOR = _FH_ENTRY,
  __module__ = 'fh_pb2'
  # @@protoc_insertion_point(class_scope:fh_entry)
  ))
_sym_db.RegisterMessage(fh_entry)

irmap_cache_entry = _reflection.GeneratedProtocolMessageType('irmap_cache_entry', (_message.Message,), dict(
  DESCRIPTOR = _IRMAP_CACHE_ENTRY,
  __module__ = 'fh_pb2'
  # @@protoc_insertion_point(class_scope:irmap_cache_entry)
  ))
_sym_db.RegisterMessage(irmap_cache_entry)


_IRMAP_CACHE_ENTRY.fields_by_name['dev'].has_options = True
_IRMAP_CACHE_ENTRY.fields_by_name['dev']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002 \001\322?\002(\001'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: inventory.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import core_pb2 as core__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='inventory.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x0finventory.proto\x1a\ncore.proto\"\xbd\x01\n\x0finventory_entry\x12\x13\n\x0bimg_version\x18\x01 \x02(\r\x12\x15\n\rfdinfo_per_id\x18\x02 \x01(\x08\x12&\n\x08root_ids\x18\x03 \x01(\x0b\x32\x14.task_kobj_ids_entry\x12\x11\n\tns_per_id\x18\x04 \x01(\x08\x12\x13\n\x0broot_cg_set\x18\x05 \x01(\r\x12\x19\n\x07lsmtype\x18\x06 \x01(\x0e\x32\x08.lsmtype\x12\x13\n\x0b\x64ump_uptime\x18\x08 \x01(\x04*0\n\x07lsmtype\x12\n\n\x06NO_LSM\x10\x00\x12\x0b\n\x07SELINUX\x10\x01\x12\x0c\n\x08\x41PPARMOR\x10\x02')
  ,
  dependencies=[core__pb2.DESCRIPTOR,])

_LSMTYPE = _descriptor.EnumDescriptor(
  name='lsmtype',
  full_name='lsmtype',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_LSM', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SELINUX', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='APPARMOR', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=223,
  serialized_end=271,
)
_sym_db.RegisterEnumDescriptor(_LSMTYPE)

lsmtype = enum_type_wrapper.EnumTypeWrapper(_LSMTYPE)
NO_LSM = 0
SELINUX = 1
APPARMOR = 2



_INVENTORY_ENTRY = _descriptor.Descriptor(
  name='inventory_entry',
  full_name='inventory_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='img_version', full_name='inventory_entry.img_version', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fdinfo_per_id', full_name='inventory_entry.fdinfo_per_id', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='root_ids', full_name='inventory_entry.root_ids', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ns_per_id', full_name='inventory_entry.ns_per_id', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='root_cg_set', full_name='inventory_entry.root_cg_set', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lsmtype', full_name='inventory_entry.lsmtype', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dump_uptime', full_name='inventory_entry.dump_uptime', index=6,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32,
  serialized_end=221,
)

_INVENTORY_ENTRY.fields_by_name['root_ids'].message_type = core__pb2._TASK_KOBJ_IDS_ENTRY
_INVENTORY_ENTRY.fields_by_name['lsmtype'].enum_type = _LSMTYPE
DESCRIPTOR.message_types_by_name['inventory_entry'] = _INVENTORY_ENTRY
DESCRIPTOR.enum_types_by_name['lsmtype'] = _LSMTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

inventory_entry = _reflection.GeneratedProtocolMessageType('inventory_entry', (_message.Message,), dict(
  DESCRIPTOR = _INVENTORY_ENTRY,
  __module__ = 'inventory_pb2'
  # @@protoc_insertion_point(class_scope:inventory_entry)
  ))
_sym_db.RegisterMessage(inventory_entry)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sa.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='sa.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x08sa.proto\x1a\nopts.proto\"\x82\x01\n\x08sa_entry\x12\x18\n\tsigaction\x18\x01 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x14\n\x05\x66lags\x18\x02 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x17\n\x08restorer\x18\x03 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x13\n\x04mask\x18\x04 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x18\n\x10\x63ompat_sigaction\x18\x05 \x01(\x08')
  ,
  dependencies=[opts__pb2.DESCRIPTOR,])




_SA_ENTRY = _descriptor.Descriptor(
  name='sa_entry',
  full_name='sa_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sigaction', full_name='sa_entry.sigaction', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='sa_entry.flags', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='restorer', full_name='sa_entry.restorer', index=2,
      number=3, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mask', full_name='sa_entry.mask', index=3,
      number=4, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='compat_sigaction', full_name='sa_entry.compat_sigaction', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25,
  serialized_end=155,
)

DESCRIPTOR.message_types_by_name['sa_entry'] = _SA_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

sa_entry = _reflection.GeneratedProtocolMessageType('sa_entry', (_message.Message,), dict(
  DESCRIPTOR = _SA_ENTRY,
  __module__ = 'sa_pb2'
  # @@protoc_insertion_point(class_scope:sa_entry)
  ))
_sym_db.RegisterMessage(sa_entry)


_SA_ENTRY.fields_by_name['sigaction'].has_options = True
_SA_ENTRY.fields_by_name['sigaction']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_SA_ENTRY.fields_by_name['flags'].has_options = True
_SA_ENTRY.fields_by_name['flags']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_SA_ENTRY.fields_by_name['restorer'].has_options = True
_SA_ENTRY.fields_by_name['restorer']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_SA_ENTRY.fields_by_name['mask'].has_options = True
_SA_ENTRY.fields_by_name['mask']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pagemap.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='pagemap.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\rpagemap.proto\x1a\nopts.proto\" \n\x0cpagemap_head\x12\x10\n\x08pages_id\x18\x01 \x02(\r\"j\n\rpagemap_entry\x12\x14\n\x05vaddr\x18\x01 \x02(\x04\x42\x05\xd2?\x02\x08\x01\x12\x10\n\x08nr_pages\x18\x02 \x02(\r\x12\x11\n\tin_parent\x18\x03 \x01(\x08\x12\x1e\n\x05\x66lags\x18\x04 \x01(\rB\x0f\xd2?\x0c\x1a\npmap.flags')
  ,
  dependencies=[opts__pb2.DESCRIPTOR,])




_PAGEMAP_HEAD = _descriptor.Descriptor(
  name='pagemap_head',
  full_name='pagemap_head',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pages_id', full_name='pagemap_head.pages_id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29,
  serialized_end=61,
)


_PAGEMAP_ENTRY = _descriptor.Descriptor(
  name='pagemap_entry',
  full_name='pagemap_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vaddr', full_name='pagemap_entry.vaddr', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nr_pages', full_name='pagemap_entry.nr_pages', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='in_parent', full_name='pagemap_entry.in_parent', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='pagemap_entry.flags', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\014\032\npmap.flags')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=63,
  serialized_end=169,
)

DESCRIPTOR.message_types_by_name['pagemap_head'] = _PAGEMAP_HEAD
DESCRIPTOR.message_types_by_name['pagemap_entry'] = _PAGEMAP_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

pagemap_head = _reflection.GeneratedProtocolMessageType('pagemap_head', (_message.Message,), dict(
  DESCRIPTOR = _PAGEMAP_HEAD,
  __module__ = 'pagemap_pb2'
  # @@protoc_insertion_point(class_scope:pagemap_head)
  ))
_sym_db.RegisterMessage(pagemap_head)

pagemap_entry = _reflection.GeneratedProtocolMessageType('pagemap_entry', (_message.Message,), dict(
  DESCRIPTOR = _PAGEMAP_ENTRY,
  __module__ = 'pagemap_pb2'
  # @@protoc_insertion_point(class_scope:pagemap_entry)
  ))
_sym_db.RegisterMessage(pagemap_entry)


_PAGEMAP_ENTRY.fields_by_name['vaddr'].has_options = True
_PAGEMAP_ENTRY.fields_by_name['vaddr']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_PAGEMAP_ENTRY.fields_by_name['flags'].has_options = True
_PAGEMAP_ENTRY.fields_by_name['flags']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\014\032\npmap.flags'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ipc-shm.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ipc_desc_pb2 as ipc__desc__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ipc-shm.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\ripc-shm.proto\x1a\x0eipc-desc.proto\"Q\n\ripc_shm_entry\x12\x1d\n\x04\x64\x65sc\x18\x01 \x02(\x0b\x32\x0f.ipc_desc_entry\x12\x0c\n\x04size\x18\x02 \x02(\x04\x12\x13\n\x0bin_pagemaps\x18\x03 \x01(\x08')
  ,
  dependencies=[ipc__desc__pb2.DESCRIPTOR,])




_IPC_SHM_ENTRY = _descriptor.Descriptor(
  name='ipc_shm_entry',
  full_name='ipc_shm_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='desc', full_name='ipc_shm_entry.desc', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='ipc_shm_entry.size', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='in_pagemaps', full_name='ipc_shm_entry.in_pagemaps', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33,
  serialized_end=114,
)

_IPC_SHM_ENTRY.fields_by_name['desc'].message_type = ipc__desc__pb2._IPC_DESC_ENTRY
DESCRIPTOR.message_types_by_name['ipc_shm_entry'] = _IPC_SHM_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ipc_shm_entry = _reflection.GeneratedProtocolMessageType('ipc_shm_entry', (_message.Message,), dict(
  DESCRIPTOR = _IPC_SHM_ENTRY,
  __module__ = 'ipc_shm_pb2'
  # @@protoc_insertion_point(class_scope:ipc_shm_entry)
  ))
_sym_db.RegisterMessage(ipc_shm_entry)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tun.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tun.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\ttun.proto\x1a\nopts.proto\"L\n\rtunfile_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x0e\n\x06netdev\x18\x02 \x01(\t\x12\x10\n\x08\x64\x65tached\x18\x03 \x01(\x08\x12\r\n\x05ns_id\x18\x04 \x01(\r\"e\n\x0etun_link_entry\x12\x14\n\x05\x66lags\x18\x01 \x02(\rB\x05\xd2?\x02\x08\x01\x12\r\n\x05owner\x18\x02 \x02(\x05\x12\r\n\x05group\x18\x03 \x02(\x05\x12\x0f\n\x07vnethdr\x18\x04 \x02(\r\x12\x0e\n\x06sndbuf\x18\x05 \x02(\r')
  ,
  dependencies=[opts__pb2.DESCRIPTOR,])




_TUNFILE_ENTRY = _descriptor.Descriptor(
  name='tunfile_entry',
  full_name='tunfile_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='tunfile_entry.id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='netdev', full_name='tunfile_entry.netdev', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='detached', full_name='tunfile_entry.detached', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ns_id', full_name='tunfile_entry.ns_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25,
  serialized_end=101,
)


_TUN_LINK_ENTRY = _descriptor.Descriptor(
  name='tun_link_entry',
  full_name='tun_link_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='flags', full_name='tun_link_entry.flags', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner', full_name='tun_link_entry.owner', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group', full_name='tun_link_entry.group', index=2,
      number=3, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vnethdr', full_name='tun_link_entry.vnethdr', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sndbuf', full_name='tun_link_entry.sndbuf', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=103,
  serialized_end=204,
)

DESCRIPTOR.message_types_by_name['tunfile_entry'] = _TUNFILE_ENTRY
DESCRIPTOR.message_types_by_name['tun_link_entry'] = _TUN_LINK_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

tunfile_entry = _reflection.GeneratedProtocolMessageType('tunfile_entry', (_message.Message,), dict(
  DESCRIPTOR = _TUNFILE_ENTRY,
  __module__ = 'tun_pb2'
  # @@protoc_insertion_point(class_scope:tunfile_entry)
  ))
_sym_db.RegisterMessage(tunfile_entry)

tun_link_entry = _reflection.GeneratedProtocolMessageType('tun_link_entry', (_message.Message,), dict(
  DESCRIPTOR = _TUN_LINK_ENTRY,
  __module__ = 'tun_pb2'
  # @@protoc_insertion_point(class_scope:tun_link_entry)
  ))
_sym_db.RegisterMessage(tun_link_entry)


_TUN_LINK_ENTRY.fields_by_name['flags'].has_options = True
_TUN_LINK_ENTRY.fields_by_name['flags']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: packet-sock.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2
import fown_pb2 as fown__pb2
import sk_opts_pb2 as sk__opts__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='packet-sock.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x11packet-sock.proto\x1a\nopts.proto\x1a\nfown.proto\x1a\rsk-opts.proto\":\n\rpacket_mclist\x12\r\n\x05index\x18\x01 \x02(\r\x12\x0c\n\x04type\x18\x02 \x02(\r\x12\x0c\n\x04\x61\x64\x64r\x18\x03 \x02(\x0c\"\x94\x01\n\x0bpacket_ring\x12\x12\n\nblock_size\x18\x01 \x02(\r\x12\x10\n\x08\x62lock_nr\x18\x02 \x02(\r\x12\x12\n\nframe_size\x18\x03 \x02(\r\x12\x10\n\x08\x66rame_nr\x18\x04 \x02(\r\x12\x12\n\nretire_tmo\x18\x05 \x02(\r\x12\x13\n\x0bsizeof_priv\x18\x06 \x02(\r\x12\x10\n\x08\x66\x65\x61tures\x18\x07 \x02(\r\"\xb6\x03\n\x11packet_sock_entry\x12\n\n\x02id\x18\x01 \x02(\r\x12\x0c\n\x04type\x18\x02 \x02(\r\x12\x10\n\x08protocol\x18\x03 \x02(\r\x12\x14\n\x05\x66lags\x18\x04 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x0f\n\x07ifindex\x18\x05 \x02(\r\x12\x19\n\x04\x66own\x18\x06 \x02(\x0b\x32\x0b.fown_entry\x12\x1c\n\x04opts\x18\x07 \x02(\x0b\x32\x0e.sk_opts_entry\x12\x0f\n\x07version\x18\x08 \x02(\r\x12\x0f\n\x07reserve\x18\t \x02(\r\x12\x10\n\x08\x61ux_data\x18\n \x02(\x08\x12\x10\n\x08orig_dev\x18\x0b \x02(\x08\x12\x10\n\x08vnet_hdr\x18\x0c \x02(\x08\x12\x0c\n\x04loss\x18\r \x02(\x08\x12\x11\n\ttimestamp\x18\x0e \x02(\r\x12\x13\n\x0b\x63opy_thresh\x18\x0f \x02(\r\x12\x1e\n\x06mclist\x18\x10 \x03(\x0b\x32\x0e.packet_mclist\x12\x1a\n\x06\x66\x61nout\x18\x11 \x01(\r:\n4294967295\x12\x1d\n\x07rx_ring\x18\x12 \x01(\x0b\x32\x0c.packet_ring\x12\x1d\n\x07tx_ring\x18\x13 \x01(\x0b\x32\x0c.packet_ring\x12\r\n\x05ns_id\x18\x14 \x01(\r')
  ,
  dependencies=[opts__pb2.DESCRIPTOR,fown__pb2.DESCRIPTOR,sk__opts__pb2.DESCRIPTOR,])




_PACKET_MCLIST = _descriptor.Descriptor(
  name='packet_mclist',
  full_name='packet_mclist',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='packet_mclist.index', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='packet_mclist.type', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='addr', full_name='packet_mclist.addr', index=2,
      number=3, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=60,
  serialized_end=118,
)


_PACKET_RING = _descriptor.Descriptor(
  name='packet_ring',
  full_name='packet_ring',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_size', full_name='packet_ring.block_size', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block_nr', full_name='packet_ring.block_nr', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frame_size', full_name='packet_ring.frame_size', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frame_nr', full_name='packet_ring.frame_nr', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='retire_tmo', full_name='packet_ring.retire_tmo', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sizeof_priv', full_name='packet_ring.sizeof_priv', index=5,
      number=6, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='features', full_name='packet_ring.features', index=6,
      number=7, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=121,
  serialized_end=269,
)


_PACKET_SOCK_ENTRY = _descriptor.Descriptor(
  name='packet_sock_entry',
  full_name='packet_sock_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='packet_sock_entry.id', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='packet_sock_entry.type', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='packet_sock_entry.protocol', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='packet_sock_entry.flags', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ifindex', full_name='packet_sock_entry.ifindex', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fown', full_name='packet_sock_entry.fown', index=5,
      number=6, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='opts', full_name='packet_sock_entry.opts', index=6,
      number=7, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='packet_sock_entry.version', index=7,
      number=8, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reserve', full_name='packet_sock_entry.reserve', index=8,
      number=9, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aux_data', full_name='packet_sock_entry.aux_data', index=9,
      number=10, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='orig_dev', full_name='packet_sock_entry.orig_dev', index=10,
      number=11, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vnet_hdr', full_name='packet_sock_entry.vnet_hdr', index=11,
      number=12, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='loss', full_name='packet_sock_entry.loss', index=12,
      number=13, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='packet_sock_entry.timestamp', index=13,
      number=14, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='copy_thresh', full_name='packet_sock_entry.copy_thresh', index=14,
      number=15, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mclist', full_name='packet_sock_entry.mclist', index=15,
      number=16, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fanout', full_name='packet_sock_entry.fanout', index=16,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=4294967295,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rx_ring', full_name='packet_sock_entry.rx_ring', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tx_ring', full_name='packet_sock_entry.tx_ring', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ns_id', full_name='packet_sock_entry.ns_id', index=19,
      number=20, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=272,
  serialized_end=710,
)

_PACKET_SOCK_ENTRY.fields_by_name['fown'].message_type = fown__pb2._FOWN_ENTRY
_PACKET_SOCK_ENTRY.fields_by_name['opts'].message_type = sk__opts__pb2._SK_OPTS_ENTRY
_PACKET_SOCK_ENTRY.fields_by_name['mclist'].message_type = _PACKET_MCLIST
_PACKET_SOCK_ENTRY.fields_by_name['rx_ring'].message_type = _PACKET_RING
_PACKET_SOCK_ENTRY.fields_by_name['tx_ring'].message_type = _PACKET_RING
DESCRIPTOR.message_types_by_name['packet_mclist'] = _PACKET_MCLIST
DESCRIPTOR.message_types_by_name['packet_ring'] = _PACKET_RING
DESCRIPTOR.message_types_by_name['packet_sock_entry'] = _PACKET_SOCK_ENTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

packet_mclist = _reflection.GeneratedProtocolMessageType('packet_mclist', (_message.Message,), dict(
  DESCRIPTOR = _PACKET_MCLIST,
  __module__ = 'packet_sock_pb2'
  # @@protoc_insertion_point(class_scope:packet_mclist)
  ))
_sym_db.RegisterMessage(packet_mclist)

packet_ring = _reflection.GeneratedProtocolMessageType('packet_ring', (_message.Message,), dict(
  DESCRIPTOR = _PACKET_RING,
  __module__ = 'packet_sock_pb2'
  # @@protoc_insertion_point(class_scope:packet_ring)
  ))
_sym_db.RegisterMessage(packet_ring)

packet_sock_entry = _reflection.GeneratedProtocolMessageType('packet_sock_entry', (_message.Message,), dict(
  DESCRIPTOR = _PACKET_SOCK_ENTRY,
  __module__ = 'packet_sock_pb2'
  # @@protoc_insertion_point(class_scope:packet_sock_entry)
  ))
_sym_db.RegisterMessage(packet_sock_entry)


_PACKET_SOCK_ENTRY.fields_by_name['flags'].has_options = True
_PACKET_SOCK_ENTRY.fields_by_name['flags']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mnt.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opts_pb2 as opts__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='mnt.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\tmnt.proto\x1a\nopts.proto\"\xe7\x02\n\tmnt_entry\x12\x0e\n\x06\x66stype\x18\x01 \x02(\r\x12\x0e\n\x06mnt_id\x18\x02 \x02(\r\x12\x17\n\x08root_dev\x18\x03 \x02(\rB\x05\xd2?\x02 \x01\x12\x15\n\rparent_mnt_id\x18\x04 \x02(\r\x12\x14\n\x05\x66lags\x18\x05 \x02(\rB\x05\xd2?\x02\x08\x01\x12\x0c\n\x04root\x18\x06 \x02(\t\x12\x12\n\nmountpoint\x18\x07 \x02(\t\x12\x0e\n\x06source\x18\x08 \x02(\t\x12\x0f\n\x07options\x18\t \x02(\t\x12\x11\n\tshared_id\x18\n \x01(\r\x12\x11\n\tmaster_id\x18\x0b \x01(\r\x12\x13\n\x0bwith_plugin\x18\x0c \x01(\x08\x12\x11\n\text_mount\x18\r \x01(\x08\x12\x0e\n\x06\x66sname\x18\x0e \x01(\t\x12\x18\n\x10internal_sharing\x18\x0f \x01(\x08\x12\x0f\n\x07\x64\x65leted\x18\x10 \x01(\x08\x12\x17\n\x08sb_flags\x18\x11 \x01(\rB\x05\xd2?\x02\x08\x01\x12\x0f\n\x07\x65xt_key\x18\x12 \x01(\t*\x83\x02\n\x06\x66stype\x12\x0f\n\x0bUNSUPPORTED\x10\x00\x12\x08\n\x04PROC\x10\x01\x12\t\n\x05SYSFS\x10\x02\x12\x0c\n\x08\x44\x45VTMPFS\x10\x03\x12\x0f\n\x0b\x42INFMT_MISC\x10\x04\x12\t\n\x05TMPFS\x10\x05\x12\n\n\x06\x44\x45VPTS\x10\x06\x12\t\n\x05SIMFS\x10\x07\x12\n\n\x06PSTORE\x10\x08\x12\x0e\n\nSECURITYFS\x10\t\x12\x0b\n\x07\x46USECTL\x10\n\x12\x0b\n\x07\x44\x45\x42UGFS\x10\x0b\x12\n\n\x06\x43GROUP\x10\x0c\x12\x08\n\x04\x41UFS\x10\r\x12\n\n\x06MQUEUE\x10\x0e\x12\x08\n\x04\x46USE\x10\x0f\x12\x08\n\x04\x41UTO\x10\x10\x12\r\n\tOVERLAYFS\x10\x11\x12\n\n\x06\x41UTOFS\x10\x12\x12\x0b\n\x07TRACEFS\x10\x13')
  ,
  dependencies=[opts__pb2.DESCRIPTOR,])

_FSTYPE = _descriptor.EnumDescriptor(
  name='fstype',
  full_name='fstype',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSUPPORTED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROC', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SYSFS', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEVTMPFS', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BINFMT_MISC', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TMPFS', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEVPTS', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SIMFS', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PSTORE', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SECURITYFS', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FUSECTL', index=10, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEBUGFS', index=11, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CGROUP', index=12, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUFS', index=13, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MQUEUE', index=14, number=14,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FUSE', index=15, number=15,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTO', index=16, number=16,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OVERLAYFS', index=17, number=17,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUTOFS', index=18, number=18,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRACEFS', index=19, number=19,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=388,
  serialized_end=647,
)
_sym_db.RegisterEnumDescriptor(_FSTYPE)

fstype = enum_type_wrapper.EnumTypeWrapper(_FSTYPE)
UNSUPPORTED = 0
PROC = 1
SYSFS = 2
DEVTMPFS = 3
BINFMT_MISC = 4
TMPFS = 5
DEVPTS = 6
SIMFS = 7
PSTORE = 8
SECURITYFS = 9
FUSECTL = 10
DEBUGFS = 11
CGROUP = 12
AUFS = 13
MQUEUE = 14
FUSE = 15
AUTO = 16
OVERLAYFS = 17
AUTOFS = 18
TRACEFS = 19



_MNT_ENTRY = _descriptor.Descriptor(
  name='mnt_entry',
  full_name='mnt_entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fstype', full_name='mnt_entry.fstype', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mnt_id', full_name='mnt_entry.mnt_id', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='root_dev', full_name='mnt_entry.root_dev', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002 \001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parent_mnt_id', full_name='mnt_entry.parent_mnt_id', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='mnt_entry.flags', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='root', full_name='mnt_entry.root', index=5,
      number=6, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mountpoint', full_name='mnt_entry.mountpoint', index=6,
      number=7, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='mnt_entry.source', index=7,
      number=8, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='options', full_name='mnt_entry.options', index=8,
      number=9, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shared_id', full_name='mnt_entry.shared_id', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='master_id', full_name='mnt_entry.master_id', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='with_plugin', full_name='mnt_entry.with_plugin', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ext_mount', full_name='mnt_entry.ext_mount', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fsname', full_name='mnt_entry.fsname', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='internal_sharing', full_name='mnt_entry.internal_sharing', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deleted', full_name='mnt_entry.deleted', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sb_flags', full_name='mnt_entry.sb_flags', index=16,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ext_key', full_name='mnt_entry.ext_key', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26,
  serialized_end=385,
)

DESCRIPTOR.message_types_by_name['mnt_entry'] = _MNT_ENTRY
DESCRIPTOR.enum_types_by_name['fstype'] = _FSTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

mnt_entry = _reflection.GeneratedProtocolMessageType('mnt_entry', (_message.Message,), dict(
  DESCRIPTOR = _MNT_ENTRY,
  __module__ = 'mnt_pb2'
  # @@protoc_insertion_point(class_scope:mnt_entry)
  ))
_sym_db.RegisterMessage(mnt_entry)


_MNT_ENTRY.fields_by_name['root_dev'].has_options = True
_MNT_ENTRY.fields_by_name['root_dev']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002 \001'))
_MNT_ENTRY.fields_by_name['flags'].has_options = True
_MNT_ENTRY.fields_by_name['flags']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
_MNT_ENTRY.fields_by_name['sb_flags'].has_options = True
_MNT_ENTRY.fields_by_name['sb_flags']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\322?\002\010\001'))
# @@protoc_insertion_point(module_scope)
